==> gclcvs_2.7.0-36.tar.gz: gclcvs-2.7.0/clcs/sys-proclaim.lisp <==

(IN-PACKAGE "CONDITIONS") 
(PROCLAIM
    '(FTYPE (FUNCTION (T T T T) *)
            |(PCL::FAST-METHOD PRINT-OBJECT (PACKAGE-ERROR T))|
            COERCE-TO-CONDITION
            |(PCL::FAST-METHOD PRINT-OBJECT (CASE-FAILURE T))|
            |(PCL::FAST-METHOD PRINT-OBJECT (TYPE-ERROR T))|
            |(PCL::FAST-METHOD PRINT-OBJECT (INTERNAL-SIMPLE-ERROR T))|
            |(PCL::FAST-METHOD PRINT-OBJECT (UNBOUND-VARIABLE T))|
            |(PCL::FAST-METHOD PRINT-OBJECT (SIMPLE-CONDITION T))|
            |(PCL::FAST-METHOD PRINT-OBJECT (INTERNAL-ERROR T))|
            |(PCL::FAST-METHOD PRINT-OBJECT (END-OF-FILE T))|
            |(PCL::FAST-METHOD PRINT-OBJECT (ABORT-FAILURE T))|
            |(PCL::FAST-METHOD PRINT-OBJECT (UNDEFINED-FUNCTION T))|)) 
(PROCLAIM
    '(FTYPE (FUNCTION (T T T) *) EXECUTE-DEBUGGER-COMMAND
            RESTART-PRINT)) 
(PROCLAIM
    '(FTYPE (FUNCTION (T T T T T *) *) CLCS-UNIVERSAL-ERROR-HANDLER)) 
(PROCLAIM
    '(FTYPE (FUNCTION (T T T T) T)
            |(PCL::FAST-METHOD PRINT-OBJECT (CONDITION T))|)) 
(PROCLAIM '(FTYPE (FUNCTION (T T T *) T) SET-INTERNAL-ERROR)) 
(PROCLAIM '(FTYPE (FUNCTION (T T *) T) CERROR)) 
(PROCLAIM '(FTYPE (FUNCTION (T T T) T) ACCUMULATE-CASES)) 
(PROCLAIM
    '(FTYPE (FUNCTION NIL *) ABORT CONTINUE MUFFLE-WARNING
            SYSTEM::BREAK-HELP SYSTEM::BREAK-RESUME)) 
(PROCLAIM
    '(FTYPE (FUNCTION NIL T) READ-EVALUATED-FORM INSTALL-CLCS-SYMBOLS
            REVERT-CLCS-SYMBOLS INITIALIZE-INTERNAL-ERROR-TABLE
            KCL-TOP-RESTARTS READ-DEBUG-COMMAND)) 
(PROCLAIM '(FTYPE (FUNCTION (*) *) CLCS-COMPILE INVOKE-DEBUGGER)) 
(PROCLAIM
    '(FTYPE (FUNCTION (T) *) COMPILER::CMP-TOPLEVEL-EVAL
            SIMPLE-ASSERTION-FAILURE INVOKE-RESTART-INTERACTIVELY
            STORE-VALUE USE-VALUE 
            SYSTEM::CLCS-BREAK-LEVEL-INVOKE-RESTART CLCS-ERROR-SET)) 
(PROCLAIM
    '(FTYPE (FUNCTION (*) T) SHOW-RESTARTS BREAK COMPUTE-RESTARTS
            MAKE-RESTART SYSTEM::CLCS-BREAK-QUIT)) 
(PROCLAIM
    '(FTYPE (FUNCTION (T) T) RESET-FUNCTION
            ESCAPE-SPECIAL-CASES-REPLACE STANDARD-DEBUGGER
            SIMPLE-CONDITION-CLASS-P CONDITIONP RESTART-NAME
            CONDITION-CLASS-P UNIQUE-ID RESTART-P RESTART-FUNCTION
            RESTART-REPORT-FUNCTION RESTART-INTERACTIVE-FUNCTION
            MAKE-KCL-TOP-RESTART SYSTEM::CLCS-TERMINAL-INTERRUPT
            FIND-KCL-TOP-RESTART CONDITION-BACKTRACE REVERT-SYMBOL)) 
(PROCLAIM
    '(FTYPE (FUNCTION (T *) *) CLCS-COMPILE-FILE CLCS-LOAD ERROR
            CLCS-OPEN MAKE-CONDITION INVOKE-RESTART)) 
(PROCLAIM
    '(FTYPE (FUNCTION (T *) T) WARN SIGNAL FIND-RESTART
            SYSTEM::CLCS-BREAK-LEVEL)) 
(PROCLAIM
    '(FTYPE (FUNCTION (T T) *) ASSERT-PROMPT PARSE-KEYWORD-PAIRS
            RESTART-REPORT)) 
(PROCLAIM
    '(FTYPE (FUNCTION (T T) T) ASSERT-REPORT
            INTERNAL-SIMPLE-ERROR-PRINTER SIMPLE-CONDITION-PRINTER
            INSTALL-SYMBOL))

==> gclcvs_2.7.0-64.tar.gz: gclcvs-2.7.0/clcs/sys-proclaim.lisp <==

(IN-PACKAGE "CONDITIONS") 
(PROCLAIM
    '(FTYPE (FUNCTION (T *) NIL) ERROR))
(PROCLAIM
    '(FTYPE (FUNCTION (SYMBOL T T *) T) CHECK-TYPE-INTERNAL))
(PROCLAIM
    '(FTYPE (FUNCTION (T T T T) *)
            |(PCL::FAST-METHOD PRINT-OBJECT (PACKAGE-ERROR T))|
            COERCE-TO-CONDITION
            |(PCL::FAST-METHOD PRINT-OBJECT (CASE-FAILURE T))|
            |(PCL::FAST-METHOD PRINT-OBJECT (TYPE-ERROR T))|
            |(PCL::FAST-METHOD PRINT-OBJECT (INTERNAL-SIMPLE-ERROR T))|
            |(PCL::FAST-METHOD PRINT-OBJECT (UNBOUND-VARIABLE T))|
            |(PCL::FAST-METHOD PRINT-OBJECT (SIMPLE-CONDITION T))|
            |(PCL::FAST-METHOD PRINT-OBJECT (INTERNAL-ERROR T))|
            |(PCL::FAST-METHOD PRINT-OBJECT (END-OF-FILE T))|
            |(PCL::FAST-METHOD PRINT-OBJECT (ABORT-FAILURE T))|
            |(PCL::FAST-METHOD PRINT-OBJECT (UNDEFINED-FUNCTION T))|)) 
(PROCLAIM
    '(FTYPE (FUNCTION (T T T) *) EXECUTE-DEBUGGER-COMMAND
            RESTART-PRINT)) 
(PROCLAIM
    '(FTYPE (FUNCTION (T T T T T *) *) CLCS-UNIVERSAL-ERROR-HANDLER)) 
(PROCLAIM
    '(FTYPE (FUNCTION (T T T T) T)
            |(PCL::FAST-METHOD PRINT-OBJECT (CONDITION T))|)) 
(PROCLAIM '(FTYPE (FUNCTION (T T T *) T) SET-INTERNAL-ERROR)) 
(PROCLAIM '(FTYPE (FUNCTION (T T *) T) CERROR)) 
(PROCLAIM '(FTYPE (FUNCTION (T T T) T) ACCUMULATE-CASES)) 
(PROCLAIM
    '(FTYPE (FUNCTION NIL *) ABORT CONTINUE MUFFLE-WARNING
            SYSTEM::BREAK-HELP SYSTEM::BREAK-RESUME)) 
(PROCLAIM
    '(FTYPE (FUNCTION NIL T) READ-EVALUATED-FORM INSTALL-CLCS-SYMBOLS
            REVERT-CLCS-SYMBOLS INITIALIZE-INTERNAL-ERROR-TABLE
            KCL-TOP-RESTARTS READ-DEBUG-COMMAND)) 
;(PROCLAIM '(FTYPE (FUNCTION (*) (si::returns-exactly)) INVOKE-DEBUGGER)) ;FIXME nil return types
(PROCLAIM '(FTYPE (FUNCTION (*) *) CLCS-COMPILE)) 
(PROCLAIM
    '(FTYPE (FUNCTION (T) *) COMPILER::CMP-TOPLEVEL-EVAL
            SIMPLE-ASSERTION-FAILURE INVOKE-RESTART-INTERACTIVELY
            STORE-VALUE USE-VALUE 
            SYSTEM::CLCS-BREAK-LEVEL-INVOKE-RESTART CLCS-ERROR-SET)) 
(PROCLAIM
    '(FTYPE (FUNCTION (*) T) SHOW-RESTARTS BREAK COMPUTE-RESTARTS
            MAKE-RESTART SYSTEM::CLCS-BREAK-QUIT)) 
(PROCLAIM
    '(FTYPE (FUNCTION (T) T) RESET-FUNCTION
            ESCAPE-SPECIAL-CASES-REPLACE STANDARD-DEBUGGER
            SIMPLE-CONDITION-CLASS-P CONDITIONP RESTART-NAME
            CONDITION-CLASS-P UNIQUE-ID RESTART-P RESTART-FUNCTION
            RESTART-REPORT-FUNCTION RESTART-INTERACTIVE-FUNCTION
            MAKE-KCL-TOP-RESTART SYSTEM::CLCS-TERMINAL-INTERRUPT
            FIND-KCL-TOP-RESTART CONDITION-BACKTRACE REVERT-SYMBOL)) 
(PROCLAIM
    '(FTYPE (FUNCTION (T *) *) CLCS-COMPILE-FILE CLCS-LOAD 
            CLCS-OPEN MAKE-CONDITION INVOKE-RESTART)) 
(PROCLAIM
    '(FTYPE (FUNCTION (T *) T) WARN SIGNAL FIND-RESTART
            SYSTEM::CLCS-BREAK-LEVEL)) 
(PROCLAIM
    '(FTYPE (FUNCTION (T T) *) ASSERT-PROMPT PARSE-KEYWORD-PAIRS
            RESTART-REPORT)) 
(PROCLAIM
    '(FTYPE (FUNCTION (T T) T) ASSERT-REPORT
            INTERNAL-SIMPLE-ERROR-PRINTER SIMPLE-CONDITION-PRINTER
            INSTALL-SYMBOL))
